@@ -17,7 +17,7 @@ import storages.backends.s3boto
 from django.core.cache.backends.base import BaseCache
 
 class AmazonS3Cache(BaseCache):
-    def __init__(self, location=None, params):
+    def __init__(self, location, params):
         """
             location is not used but otherwise Django crashes.
         """
